/*
date: 5.14.2018

purpose: demand for each preventative, black vs. white doctor, pre- and post-consultation
		
input: "$drive\3output_data\oakland_analysis_final.dta"

output: 
		Panel A - figure3_bmi.pdf - Blood pressure
		Panel B - figure3_bp.pdf - Body mass index
		Panel C - figure3_dia.pdf - Cholesterol
		Panel D - figure3_cho.pdf - Diabetes
		Panel E - figure3_flu_nosl.pdf - Flu shot, with incentive
		Panel F - figure3_flu_sl.pdf - Flu shot, without incentive

author: MF

*/


clear
set more off 

log using "$drive\4log\figure3_demand.smcl", replace


	use "$drive\3output_data\oakland_analysis_final.dta", clear 
	
	collapse (mean) pre_bmi pre_bp pre_cho pre_dia pre_flu_sl pre_flu_nosl ///
					post_bmi post_bp post_cho post_dia post_flu_sl post_flu_nosl ///
					if tag == 1, by(black_dr)
					
	reshape long pre_ post_, i(black_dr) j(test) string
	rename pre_ test_1
	rename post_ test_2
	reshape long test_, i(black_dr test) j(type)
	gen ex = 1 if type == 1 & black_dr == 0
		replace ex = 2 if type == 1 & black_dr == 1
		replace ex = 4 if type == 2 & black_dr == 0
		replace ex = 5 if type == 2 & black_dr == 1	
	
	local alltests bmi bp dia cho flu_nosl flu_sl
	foreach x of local alltests {	
	twoway bar test_ ex if test == `"`x'"' & black_dr==0, color(gs12)  || ///
		   bar test_ ex if test == `"`x'"' & black_dr==1, color(ebblue) ///
			  legend(row(1) order(1 "Non-Black Doctor" 2 "Black Doctor")) yscale(r(0, 1)) ytitle("") ///
			  ylabel(0 "0" .2 "20" .4 "40" .6 "60" .8 "80" 1 "100%", angle(0)) ///
			  xtitle("") xlabel(1.5 "Pre-Consultation" 4.5 "Post-Consultation", notick)  ///
			  plotregion(margin(b=0))
	graph export `"$drive\5figures\figure3_`x'.pdf"', replace	
	}	

			
log  close			
