/*
date: 2.6.2019

purpose: post demand by invasiveness (Panel A) and persuasion rates (Panel B)
		
input: "$drive\3output_data\oakland_analysis_final.dta"

output: 
		Panel A - "$drive\5figures\figure4A_scatter.pdf"
		Panel B - "$drive\5figures\figure4B_persuasion.pdf"

author: MF

*/


clear
set more off 	

log using "$drive\4log\figure4_persuasion.smcl", replace



******************************************
 *FIGURE 4A: DIFFRENCE IN POST BY EXAM*		
******************************************

	use "$drive\3output_data\oakland_analysis_final.dta", clear 
	
*NOTE: additional formatting of figure done outside of stata.	
 preserve
	collapse (mean) post_bmi post_bp post_cho post_dia post_flu_nosl ///
		     (sem)  sepost_bmi = post_bmi sepost_bp = post_bp sepost_cho = post_cho sepost_dia = post_dia sepost_flu_nosl = post_flu_nosl ///
					if tag == 1, by(black_dr)
	reshape long post_ sepost_, i(black_dr) j(test) string
	gen upper_ = post_ + sepost_
	gen lower_ = post_ - sepost_
	drop sepost_
	reshape wide post_ upper_ lower_, i(test) j(black_dr) 
	
	gen delta_post = (post_1 - post_0)
	gen pctdelta_post = (post_1 - post_0) / post_0
	gen pctdelta_lower = (lower_1 - lower_0) / lower_0 
	gen pctdelta_upper = (upper_1 - upper_0) / upper_0 	
	sort pctdelta_post 
	gen ltest = _n
	
	replace ltest = 3 if test == "flu_sl"
	replace ltest = 2 if test == "bmi"

	scatter pctdelta_post ltest if test == "bp", msymbol(circle) msize(huge) color("188 0 44") || ///
	scatter pctdelta_post ltest if test == "bmi", msymbol(circle) msize(huge) color("188 0 138") || ///
	scatter pctdelta_post ltest if test == "dia", msymbol(circle) msize(huge) color("146 7 189") || ///
	scatter pctdelta_post ltest if test == "flu_nosl", msymbol(cirlce) msize(huge) color("50 0 188") || ///
	scatter pctdelta_post ltest if test == "cho", msymbol(cirlce) msize(huge) color("191 151 18") ///
	xlabel(1 "BP" 2 "BMI" 3 "Diabetes" 4 "Flu No $" 5 "Chol", notick) ytitle("Post Selection: Black vs. Non-Black (%)")  ///
	xscale(r(.8 5.2)) yscale(r(0 1)) ///	
	xtitle("") ylabel(0 "0" .2 "20" .4 "40" .6 "60" .8 "80" 1 "100%", angle(0)) legend(off) plotregion(margin(b=0))
	graph export `"$drive\5figures\figure4A_scatter.pdf"', replace	
restore
	
	
	
*******************************
 *FIGURE 4B: PERSUASION RATES*		
*******************************

import excel using "$drive\2input_data\persuasion.xlsx", firstrow clear /*study + DellaVigna/Gentzkow rates*/

 gen yindex = ( -1*_n)
 replace rate = rate*100
  
 	twoway bar rate yindex if oakland != 1, color(gs12)  || ///
		   bar rate yindex if oakland == 1, color(ebblue)  ///
		   ytitle("Persuasion Rate (%)") xtitle("") legend(order(1 "DG Studies" 2 "Oakland Study")) ///
		   ylabel(, angle(0)) ///
		   plotregion(margin(b=0)) xlabel("", noticks)
	graph export "$drive\5figures\figure4B_persuasion.pdf", replace
	
log close	
