/*
date: 5.15.2018

purpose: qualtrics concordance preference by question
		
input: "$drive\3output_data\qualtrics_clean_long.dta"

output: "$drive\5figures\figure5_qualtrics.pdf"

author: MF

*/


clear
set more off 

log using "$drive\4log\figure5_qualtrics.smcl", replace

use "$drive\3output_data\qualtrics_clean_long.dta", clear
	
	collapse (mean) concordance, by(black_resp question)
	drop if question == "adviceQ" | question == "work_hardestQ" | question == "medneedsQ" | question == "mistakeQ" |  question == "medcareQ"
	gsort -black_resp -concordance 
	gen lx = _n if black_resp == 1
		bys question: egen lxmin = min(lx)	
			replace lxmin = (lxmin)*-1
	replace concordance = concordance * 100
	
	twoway scatter lxmin concordance if black_resp == 1, color(ebblue) msymbol(O) msize(large) || ///
		   scatter lxmin concordance if black_resp == 0, color(gs10) msymbol(O) msize(large) ///
		   ylabel(-1 "understand your concerns best?" -2 "you be comfortable discussing concerns with?" ///
				  -3 "give you appropriate treatment?" -4 "be the most qualified?" -5 "be available near you?", angle(0) notick nogrid labsize(small)) ///
		   ytitle("") xtitle("Percentage selecting MD of same race", size(small)) xlabel(35(5)75, labsize(vsmall) grid) ///
		   title("Which doctor would...", size(medium)) xline(50, lcolor("188 0 44")) plotr(m(zero)) ///
		   legend(size(small) row(1) order(1 "Black Respondent" 2 "White Respondent")) xscale(r(35 75)) yscale(r(-5.2 -0.8))
	graph export "$drive\5figures\figure5_qualtrics.pdf", replace 
	
log close	
