/*
date: 4.1.2019

purpose: doctor fixed effects table
		
input:
1) "$drive\3output_data\oakland_analysis_final.dta"
2) "$drive\2input_data\md_chars.dta" - MD characteristics data
3) "$drive\3output_data\race_combinations_6black.dta" - RI permutations
4) "$drive\3output_data\md_survey.dta" - MD survey

output: none - data are protected 

author: MF

*/

clear
set more off 
cap log close 



	est clear 
	use "$drive\3output_data\oakland_analysis_final.dta", clear 

	encode doctor_id, gen(DFE) 
	reghdfe delta_shr_invasive, absorb(FE1 = DFE) 
	bys doctor_id: gen first = _n 
	keep if first == 1  
	keep FE1 doctor_id black_dr
	rename FE1 coef 
			merge 1:m doctor_id using "$drive\3output_data\md_chars_MA.dta", force
				drop _merge
				
	merge 1:1 doctor_id using "$drive\3output_data\md_survey_MA.dta"
				drop _merge
			
*Column 1: FE on black doctor	
	reg coef black_dr, r
		est store c1
				ritest black_dr _b[black_dr], reps(3003) samplingsourcefile("$drive\3output_data\race_combinations_6black.dta") ///
							samplingmatchvar(doctor_id): ///
							reg coef black_dr
					local temp = el(r(p),1,1)
					est restore c1
					estadd scalar ri_p = `temp'

*Columns 2-5: FE on black doctor + doctor characteristic					
	foreach var in ptsblack_grtr5 top10 years_exp internist {
		reg coef black_dr `var', r
			est store `var'1
					ritest black_dr _b[black_dr], reps(3003) samplingsourcefile("$drive\3output_data\race_combinations_6black.dta") ///
								samplingmatchvar(doctor_id): ///
								reg coef black_dr `var', r
						local temp = el(r(p),1,1)
						est restore `var'1
						estadd scalar ri_p = `temp'
	}					

*Column 6: FE on black doctor and all doctor characteristics	
	reg coef black_dr ptsblack_grtr5 top10 years_exp internist, r
		est store c6
				ritest black_dr _b[black_dr], reps(3003) samplingsourcefile("$drive\3output_data\race_combinations_6black.dta") ///
							samplingmatchvar(doctor_id): ///
							reg coef black_dr ptsblack_grtr5 top10 years_exp internist
					local temp = el(r(p),1,1)
					est restore c6
					estadd scalar ri_p = `temp'		
						
	esttab _all using "$drive\6tables\table9_doctorFE.csv", stats(ri_p N r2) b(3) se nostar replace 
		
		
log close	  	
